# SPML2-mltools
[![Python package](https://github.com/SermetPekin/spml2/actions/workflows/package.yml/badge.svg)](https://github.com/SermetPekin/spml2/actions/workflows/package.yml)
[![Pypi - Daily full versions](https://github.com/SermetPekin/spml2/actions/workflows/pypi-full.yml/badge.svg)](https://github.com/SermetPekin/spml2/actions/workflows/pypi-full.yml)
[![PyPI](https://img.shields.io/pypi/v/spml2_mltools)](https://img.shields.io/pypi/v/spml2) ![t](https://img.shields.io/badge/status-maintained-yellow.svg) [![](https://img.shields.io/badge/python-3.10+-blue.svg)](https://www.python.org/downloads/)



## Installation

```bash
pip install spml2-mltools

```
## Usage

```bash

spml2 web.py

```


---
## Features
- Web Runner
- ROC curves
- Feature importances
- SHAP graphs
---
